Index: includes/CategoryPage.php
===================================================================
--- includes/CategoryPage.php (revisión: 36)
+++ includes/CategoryPage.php (copia de trabajo)
@@ -1,4 +1,4 @@
-<?php
+ <?php
/**
* Special handling for category description pages
* Modelled after ImagePage.php
@@ -102,7 +102,8 @@
'LIMIT' => $limit + 1 ) );
$sk =& $wgUser->getSkin();
- $r = "<br style=\"clear:both;\"/>\n";
+ //EOL
+ //$r = "<br style=\"clear:both;\"/>\n";
$count = 0;
$nextPage = null;
while( $x = $dbr->fetchObject ( $res ) ) {
Index: includes/Defines.php
===================================================================
--- includes/Defines.php (revisión: 36)
+++ includes/Defines.php (copia de trabajo)
@@ -164,5 +164,8 @@
define( 'RC_MOVE_OVER_REDIRECT', 4);
/**#@-*/
+//EOL
+define( 'EOL_PROFILE', '/member.php?action=getinfo&userid=' );
+define( 'EOL_PROFILEF', 'http://www.elotrolado.net' . EOL_PROFILE );
?>
Index: includes/User.php
===================================================================
--- includes/User.php (revisión: 36)
+++ includes/User.php (copia de trabajo)
@@ -142,13 +142,16 @@
function idFromName( $name ) {
$fname = "User::idFromName";
- $nt = Title::newFromText( $name );
- if( is_null( $nt ) ) {
- # Illegal name
- return null;
- }
+ //EOL
+// $nt = Title::newFromText( $name );
+// if( is_null( $nt ) ) {
+// # Illegal name
+// return null;
+// }
+
$dbr =& wfGetDB( DB_SLAVE );
- $s = $dbr->selectRow( 'user', array( 'user_id' ), array( 'user_name' => $nt->getText() ), $fname );
+// $s = $dbr->selectRow( 'user', array( 'user_id' ), array( 'user_name' => $nt->getText() ), $fname );
+ $s = $dbr->selectRow( 'user', array( 'user_id' ), array( 'user_name' => $name ), $fname );
if ( $s === false ) {
return 0;
@@ -720,7 +723,7 @@
array( 'user_id' => $this->mId ), $fname );
if ( $s !== false ) {
- $this->mName = $s->user_name;
+ $this->mName = html_entity_decode($s->user_name);
$this->mEmail = $s->user_email;
$this->mEmailAuthenticated = wfTimestampOrNull( TS_MW, $s->user_email_authenticated );
$this->mRealName = $s->user_real_name;
@@ -1565,7 +1568,9 @@
* @access public
*/
function getUserPage() {
- return Title::makeTitle( NS_USER, $this->getName() );
+//EOL
+// return Title::makeTitle( NS_USER, $this->getName() );
+ return EOL_PROFILE .$mId;
}
/**
@@ -1575,8 +1580,8 @@
* @access public
*/
function getTalkPage() {
- $title = $this->getUserPage();
- return $title->getTalkPage();
+// $title = $this->getUserPage();
+// return $title->getTalkPage();
}
/**
Index: includes/Article.php
===================================================================
--- includes/Article.php (revisión: 36)
+++ includes/Article.php (copia de trabajo)
@@ -2132,8 +2132,11 @@
return;
}
- $from = str_replace( '_', ' ', $wgRequest->getVal( 'from' ) );
- if( $from != $current->getUserText() ) {
+ //EOL
+// $from = str_replace( '_', ' ', $wgRequest->getVal( 'from' ) );
+ $from = intval($wgRequest->getVal( 'from' ));
+// if( $from != $current->getUserText() ) {
+ if( $from != $current->mUser ) {
$wgOut->setPageTitle( wfMsg('rollbackfailed') );
$wgOut->addWikiText( wfMsg( 'alreadyrolled',
htmlspecialchars( $this->mTitle->getPrefixedText()),
Index: includes/SpecialUserlogin.php
===================================================================
--- includes/SpecialUserlogin.php (revisión: 36)
+++ includes/SpecialUserlogin.php (copia de trabajo)
@@ -35,8 +35,13 @@
*/
function LoginForm( &$request ) {
global $wgLang, $wgAllowRealName, $wgEnableEmail;
- global $wgAuth;
+ global $wgAuth, $wgScriptPath;
+ //EOL
+ //redirect to forum login
+ header('Location: /login.php?returnto='.$wgScriptPath.'/'.$request->getVal( 'returnto' ));
+ exit;
+
$this->mType = $request->getText( 'type' );
$this->mName = $request->getText( 'wpName' );
$this->mPassword = $request->getText( 'wpPassword' );
Index: includes/ImagePage.php
===================================================================
--- includes/ImagePage.php (revisión: 36)
+++ includes/ImagePage.php (copia de trabajo)
@@ -751,9 +751,11 @@
if ( 0 == $user ) {
$userlink = $usertext;
} else {
- $userlink = $this->skin->makeLinkObj( Title::makeTitle( NS_USER, $usertext ), $usertext );
- $usertalk = $this->skin->makeLinkObj( Title::makeTitle( NS_USER_TALK, $usertext), $wgContLang->getNsText( NS_TALK ) );
- $userdata = $userlink . ' (' . $usertalk . ')';
+ //EOL
+// $userlink = $this->skin->makeLinkObj( Title::makeTitle( NS_USER, $usertext ), $usertext );
+// $usertalk = $this->skin->makeLinkObj( Title::makeTitle( NS_USER_TALK, $usertext), $wgContLang->getNsText( NS_TALK ) );
+// $userdata = $userlink . ' (' . $usertalk . ')';
+ $userdata = '<a href="'. EOL_PROFILE ."$user\">$usertext</a>";
}
$nbytes = wfMsg( 'nbytes', $size );
$widthheight = wfMsg( 'widthheight', $width, $height );
Index: includes/Linker.php
===================================================================
--- includes/Linker.php (revisión: 36)
+++ includes/Linker.php (copia de trabajo)
@@ -759,8 +759,10 @@
return $this->makeKnownLinkObj( $contribsPage,
$encName, 'target=' . urlencode( $userText ) );
} else {
- $userPage = Title::makeTitle( NS_USER, $userText );
- return $this->makeLinkObj( $userPage, $encName );
+ //EOL
+// $userPage = Title::makeTitle( NS_USER, $userText );
+// return $this->makeLinkObj( $userPage, $encName );
+ return '<a href="'. EOL_PROFILE .$userId."\">$userText</a>";
}
}
@@ -772,7 +774,9 @@
*/
function userToolLinks( $userId, $userText ) {
global $wgUser, $wgDisableAnonTalk, $wgSysopUserBans;
- $talkable = !( $wgDisableAnonTalk && 0 == $userId );
+ //EOL
+// $talkable = !( $wgDisableAnonTalk && 0 == $userId );
+ $talkable = false;
$blockable = ( $wgSysopUserBans || 0 == $userId );
$items = array();
@@ -782,7 +786,7 @@
if( $userId ) {
$contribsPage = Title::makeTitle( NS_SPECIAL, 'Contributions' );
$items[] = $this->makeKnownLinkObj( $contribsPage,
- wfMsgHtml( 'contribslink' ), 'target=' . urlencode( $userText ) );
+ wfMsgHtml( 'contribslink' ), 'target=' . urlencode( $userId ) );
}
if( $blockable && $wgUser->isAllowed( 'block' ) ) {
$items[] = $this->blockLink( $userId, $userText );
@@ -819,7 +823,9 @@
function blockLink( $userId, $userText ) {
$blockPage = Title::makeTitle( NS_SPECIAL, 'Blockip' );
$blockLink = $this->makeKnownLinkObj( $blockPage,
- wfMsgHtml( 'blocklink' ), 'ip=' . urlencode( $userText ) );
+ //EOL
+// wfMsgHtml( 'blocklink' ), 'ip=' . urlencode( $userText ) );
+ wfMsgHtml( 'blocklink' ), 'ip=' . urlencode( $userId ) );
return $blockLink;
}
Index: includes/Parser.php
===================================================================
--- includes/Parser.php (revisión: 36)
+++ includes/Parser.php (copia de trabajo)
@@ -1010,41 +1010,41 @@
if (strlen ($r) == 2)
{
if ($state == 'i')
- { $output .= '</i>'; $state = ''; }
+ { $output .= '</em>'; $state = ''; }
else if ($state == 'bi')
- { $output .= '</i>'; $state = 'b'; }
+ { $output .= '</em>'; $state = 'b'; }
else if ($state == 'ib')
- { $output .= '</b></i><b>'; $state = 'b'; }
+ { $output .= '</strong></em><strong>'; $state = 'b'; }
else if ($state == 'both')
- { $output .= '<b><i>'.$buffer.'</i>'; $state = 'b'; }
+ { $output .= '<strong><em>'.$buffer.'</em>'; $state = 'b'; }
else # $state can be 'b' or ''
- { $output .= '<i>'; $state .= 'i'; }
+ { $output .= '<em>'; $state .= 'i'; }
}
else if (strlen ($r) == 3)
{
if ($state == 'b')
- { $output .= '</b>'; $state = ''; }
+ { $output .= '</strong>'; $state = ''; }
else if ($state == 'bi')
- { $output .= '</i></b><i>'; $state = 'i'; }
+ { $output .= '</em></strong><em>'; $state = 'i'; }
else if ($state == 'ib')
- { $output .= '</b>'; $state = 'i'; }
+ { $output .= '</strong>'; $state = 'i'; }
else if ($state == 'both')
- { $output .= '<i><b>'.$buffer.'</b>'; $state = 'i'; }
+ { $output .= '<em><strong>'.$buffer.'</strong>'; $state = 'i'; }
else # $state can be 'i' or ''
- { $output .= '<b>'; $state .= 'b'; }
+ { $output .= '<strong>'; $state .= 'b'; }
}
else if (strlen ($r) == 5)
{
if ($state == 'b')
- { $output .= '</b><i>'; $state = 'i'; }
+ { $output .= '</strong><em>'; $state = 'i'; }
else if ($state == 'i')
- { $output .= '</i><b>'; $state = 'b'; }
+ { $output .= '</em><strong>'; $state = 'b'; }
else if ($state == 'bi')
- { $output .= '</i></b>'; $state = ''; }
+ { $output .= '</em></strong>'; $state = ''; }
else if ($state == 'ib')
- { $output .= '</b></i>'; $state = ''; }
+ { $output .= '</strong></em>'; $state = ''; }
else if ($state == 'both')
- { $output .= '<i><b>'.$buffer.'</b></i>'; $state = ''; }
+ { $output .= '<em><strong>'.$buffer.'</strong></em>'; $state = ''; }
else # ($state == '')
{ $buffer = ''; $state = 'both'; }
}
@@ -1053,13 +1053,13 @@
}
# Now close all remaining tags. Notice that the order is important.
if ($state == 'b' || $state == 'ib')
- $output .= '</b>';
+ $output .= '</strong>';
if ($state == 'i' || $state == 'bi' || $state == 'ib')
- $output .= '</i>';
+ $output .= '</em>';
if ($state == 'bi')
- $output .= '</b>';
+ $output .= '</strong>';
if ($state == 'both')
- $output .= '<b><i>'.$buffer.'</i></b>';
+ $output .= '<strong><em>'.$buffer.'</em></strong>';
return $output;
}
}
@@ -3430,8 +3430,10 @@
}
# If we're still here, make it a link to the user page
- $userpage = $user->getUserPage();
- return( '[[' . $userpage->getPrefixedText() . '|' . wfEscapeWikiText( $nickname ) . ']]' );
+ // EOL
+// $userpage = $user->getUserPage();
+// return( '[[' . $userpage->getPrefixedText() . '|' . wfEscapeWikiText( $nickname ) . ']]' );
+ return '['. EOL_PROFILEF .$user->mId.' '.$username.']';
}
/**
Index: includes/EditPage.php
===================================================================
--- includes/EditPage.php (revisión: 36)
+++ includes/EditPage.php (copia de trabajo)
@@ -1130,7 +1130,7 @@
if($this->mTitle->getNamespace() == NS_CATEGORY) {
$this->mArticle->closeShowCategory();
}
- $wgOut->addHTML( "<br style=\"clear:both;\" />\n" );
+// $wgOut->addHTML( "<br style=\"clear:both;\" />\n" );
$wgOut->addHTML( '</div>' );
}
@@ -1228,6 +1228,9 @@
$fname = 'EditPage::getPreviewText';
wfProfileIn( $fname );
+
+ //not necessary, it's checked in importFormData()
+ $this->mTokenOk = true;
if ( $this->mTokenOk ) {
$msg = 'previewnote';
Index: includes/SpecialBlockip.php
===================================================================
--- includes/SpecialBlockip.php (revisión: 36)
+++ includes/SpecialBlockip.php (copia de trabajo)
@@ -166,6 +166,8 @@
} else {
# Username block
if ( $wgSysopUserBans ) {
+ //EOL
+ $this->BlockAddress = User::whoIs($this->BlockAddress);
$userId = User::idFromName( $this->BlockAddress );
if ( $userId == 0 ) {
$this->showForm( wfMsg( 'nosuchusershort', htmlspecialchars( $this->BlockAddress ) ) );
Index: includes/OutputPage.php
===================================================================
--- includes/OutputPage.php (revisión: 36)
+++ includes/OutputPage.php (copia de trabajo)
@@ -649,7 +649,9 @@
} else {
$name = $id;
}
- $link = '[[' . $wgContLang->getNsText( NS_USER ) . ":{$name}|{$name}]]";
+ //EOL
+// $link = '[[' . $wgContLang->getNsText( NS_USER ) . ":{$name}|{$name}]]";
+ $link = '['. EOL_PROFILEF ."$id $name]";
$this->addWikiText( wfMsg( 'blockedtext', $link, $reason, $ip, $name ) );
$this->returnToMain( false );
Index: includes/SpecialNewimages.php
===================================================================
--- includes/SpecialNewimages.php (revisión: 36)
+++ includes/SpecialNewimages.php (copia de trabajo)
@@ -130,13 +130,19 @@
}
$name = $s->img_name;
+
$ut = $s->img_user_text;
$nt = Title::newFromText( $name, NS_IMAGE );
$img = Image::newFromTitle( $nt );
$ul = $sk->makeLinkObj( Title::makeTitle( NS_USER, $ut ), $ut );
+
+ //EOL
+ $userId = $s->img_user;
+ $userText = $s->img_user_text;
+ $u = '<a href="'. EOL_PROFILE .$userId."\">$userText</a>";
- $gallery->add( $img, "$ul<br />\n<i>".$wgLang->timeanddate( $s->img_timestamp, true )."</i><br />\n" );
+ $gallery->add( $img, "$u<br />\n<i>".$wgLang->timeanddate( $s->img_timestamp, true )."</i><br />\n" );
$timestamp = wfTimestamp( TS_MW, $s->img_timestamp );
if( empty( $firstTimestamp ) ) {
Index: includes/SpecialImagelist.php
===================================================================
--- includes/SpecialImagelist.php (revisión: 36)
+++ includes/SpecialImagelist.php (copia de trabajo)
@@ -115,6 +115,11 @@
} else {
$ul = $sk->makeLinkObj( Title::makeTitle( NS_USER, $ut ), $ut );
}
+
+ //EOL
+ $userId = $s->img_user;
+ $userText = $s->img_user_text;
+ $u = '<a href="'. EOL_PROFILE ."$userId\">$userText</a>";
$ilink = "<a href=\"" . htmlspecialchars( Image::imageUrl( $name ) ) .
"\">" . strtr(htmlspecialchars( $name ), '_', ' ') . "</a>";
@@ -123,7 +128,7 @@
$l = "(" .
$sk->makeKnownLinkObj( Title::makeTitle( NS_IMAGE, $name ),
wfMsg( "imgdesc" ) ) .
- ") {$ilink} . . {$nb} . . {$ul} . . " .
+ ") {$ilink} . . {$nb} . . {$u} . . " .
$wgLang->timeanddate( $s->img_timestamp, true );
$l .= $sk->commentBlock( $s->img_description );
Index: includes/SpecialIpblocklist.php
===================================================================
--- includes/SpecialIpblocklist.php (revisión: 36)
+++ includes/SpecialIpblocklist.php (copia de trabajo)
@@ -104,13 +104,18 @@
$block->mAddress = $this->ip;
}
+ //EOL
+ $name = User::whoIs($this->ip);
+
# Delete block (if it exists)
# We should probably check for errors rather than just declaring success
$block->delete();
# Make log entry
$log = new LogPage( 'block' );
- $log->addEntry( 'unblock', Title::makeTitle( NS_USER, $this->ip ), $this->reason );
+ //EOL
+// $log->addEntry( 'unblock', Title::makeTitle( NS_USER, $this->ip ), $this->reason );
+ $log->addEntry( 'unblock', Title::makeTitle( NS_USER, $name ), $this->reason );
# Report to the user
$titleObj = Title::makeTitle( NS_SPECIAL, "Ipblocklist" );
@@ -216,15 +221,20 @@
# Prepare links to the blocker's user and talk pages
$blocker_name = $block->getByName();
- $blocker = $sk->MakeLinkObj( Title::makeTitle( NS_USER, $blocker_name ), $blocker_name );
- $blocker .= ' (' . $sk->makeLinkObj( Title::makeTitle( NS_USER_TALK, $blocker_name ), $wgLang->getNsText( NS_TALK ) ) . ')';
+ $blocker_id = $block->mBy;
+// $blocker = $sk->MakeLinkObj( Title::makeTitle( NS_USER, $blocker_name ), $blocker_name );
+// $blocker .= ' (' . $sk->makeLinkObj( Title::makeTitle( NS_USER_TALK, $blocker_name ), $wgLang->getNsText( NS_TALK ) ) . ')';
+ $blocker = "<a href=\"../member.php?action=getinfo&userid=$blocker_id\">$blocker_name</a>";
# Prepare links to the block target's user and contribs. pages (as applicable, don't do it for autoblocks)
if( $block->mAuto ) {
$target = '#' . $block->mId; # Hide the IP addresses of auto-blocks; privacy
} else {
- $target = $sk->makeLinkObj( Title::makeTitle( NS_USER, $block->mAddress ), $block->mAddress );
- $target .= ' (' . $sk->makeKnownLinkObj( Title::makeTitle( NS_SPECIAL, 'Contributions' ), $msg['contribslink'], 'target=' . $block->mAddress ) . ')';
+// $target = $sk->makeLinkObj( Title::makeTitle( NS_USER, $block->mAddress ), $block->mAddress );
+// $target .= ' (' . $sk->makeKnownLinkObj( Title::makeTitle( NS_SPECIAL, 'Contributions' ), $msg['contribslink'], 'target=' . $block->mAddress ) . ')';
+ $blocked_id = $block->mUser;
+ $blocked_name = $block->mAddress;
+ $target = "<a href=\"../member.php?action=getinfo&userid=$blocked_id\">$blocked_name</a>";
}
# Prep the address for the unblock link, masking autoblocks as before
@@ -245,7 +255,7 @@
if ( $wgUser->isAllowed('block') ) {
$titleObj = Title::makeTitle( NS_SPECIAL, "Ipblocklist" );
- $wgOut->addHTML( ' (' . $sk->makeKnownLinkObj($titleObj, $msg['unblocklink'], 'action=unblock&ip=' . urlencode( $addr ) ) . ')' );
+ $wgOut->addHTML( ' (' . $sk->makeKnownLinkObj($titleObj, $msg['unblocklink'], 'action=unblock&ip=' . urlencode( $block->mUser ) ) . ')' );
}
$wgOut->addHTML( $sk->commentBlock( $block->mReason ) );
$wgOut->addHTML( "</li>\n" );
Index: includes/DifferenceEngine.php
===================================================================
--- includes/DifferenceEngine.php (revisión: 36)
+++ includes/DifferenceEngine.php (copia de trabajo)
@@ -151,10 +151,16 @@
$contribs = wfMsg( 'contribslink' );
if ( $this->mNewRev->isCurrent() && $wgUser->isAllowed('rollback') ) {
- $username = $this->mNewRev->getUserText();
+// $username = $this->mNewRev->getUserText();
+// $rollback = ' <strong>[' . $sk->makeKnownLinkObj( $this->mTitle, wfMsg( 'rollbacklink' ),
+// 'action=rollback&from=' . urlencode( $username ) .
+// '&token=' . urlencode( $wgUser->editToken( array( $this->mTitle->getPrefixedText(), $username ) ) ) ) .
+// ']</strong>';
+ //EOL
+ $userid = $this->mNewRev->getUser();
$rollback = ' <strong>[' . $sk->makeKnownLinkObj( $this->mTitle, wfMsg( 'rollbacklink' ),
- 'action=rollback&from=' . urlencode( $username ) .
- '&token=' . urlencode( $wgUser->editToken( array( $this->mTitle->getPrefixedText(), $username ) ) ) ) .
+ 'action=rollback&from=' . urlencode( $userid ) .
+ '&token=' . urlencode( $wgUser->editToken( array( $this->mTitle->getPrefixedText(), $userid ) ) ) ) .
']</strong>';
} else {
$rollback = '';
Index: includes/SpecialLog.php
===================================================================
--- includes/SpecialLog.php (revisión: 36)
+++ includes/SpecialLog.php (copia de trabajo)
@@ -92,7 +92,7 @@
* @param string $name (In)valid user name
* @access private
*/
- function limitUser( $name ) {
+ function limitUser( $id ) {
if ( $name == '' )
return false;
$title = Title::makeTitle( NS_USER, $name );
@@ -101,7 +101,11 @@
$this->user = $title->getText();
$safename = $this->db->strencode( $this->user );
$user = $this->db->tableName( 'user' );
- $this->whereClauses[] = "user_name='$safename'";
+ //EOL
+// $this->whereClauses[] = "user_name='$safename'";
+// $this->whereClauses[] = "UPPER(user_name)=UPPER('$safename')";
+ $id = intval($id);
+ $this->whereClauses[] = "user='$id'";
}
/**
@@ -311,7 +315,10 @@
$linkCache->addBadLinkObj( $title );
}
- $userLink = $this->skin->makeLinkObj( $user, htmlspecialchars( $s->user_name ) );
+ //EOL
+// $userLink = $this->skin->makeLinkObj( $user, htmlspecialchars( $s->user_name ) );
+ $userLink = '<a href="' . EOL_PROFILE .$s->log_user.'">'.htmlspecialchars( $s->user_name ).'</a>';
+
$comment = $this->skin->commentBlock( $s->log_comment );
$paramArray = LogPage::extractParams( $s->log_params );
$revert = '';
Index: includes/SkinTemplate.php
===================================================================
--- includes/SkinTemplate.php (revisión: 36)
+++ includes/SkinTemplate.php (copia de trabajo)
@@ -167,8 +167,9 @@
$this->iscontent = ($this->mTitle->getNamespace() != NS_SPECIAL );
$this->iseditable = ($this->iscontent and !($action == 'edit' or $action == 'submit'));
$this->username = $wgUser->getName();
- $userPage = $wgUser->getUserPage();
- $this->userpage = $userPage->getPrefixedText();
+// EOL
+// $userPage = $wgUser->getUserPage();
+// $this->userpage = $userPage->getPrefixedText();
if ( $wgUser->isLoggedIn() || $this->showIPinHeader() ) {
$this->userpageUrlDetails = $this->makeUrlDetails($this->userpage);
@@ -400,7 +401,7 @@
wfProfileOut( "$fname-stuff4" );
# Personal toolbar
- $tpl->set('personal_urls', $this->buildPersonalUrls());
+// $tpl->set('personal_urls', $this->buildPersonalUrls());
$content_actions = $this->buildContentActionUrls();
$tpl->setRef('content_actions', $content_actions);
@@ -419,6 +420,14 @@
$tpl->set( 'sidebar', $this->buildSidebar() );
$tpl->set( 'nav_urls', $this->buildNavUrls() );
+ //EOL
+ //various templates
+ $tpl->set('banner-top', get_bannertop() );
+ $tpl->set('banner-left', get_bannerleft() );
+ $tpl->set('menu', get_menu() );
+ $tpl->set('loggedin',$this->loggedin);
+ $tpl->set('loggedusername',$this->username);
+
// execute template
wfProfileIn( "$fname-execute" );
$res = $tpl->execute();
@@ -992,7 +1001,47 @@
wfProfileOut( $fname );
return $s;
}
+
+ function reallyDoGetUserStyles() {
+ global $wgUser;
+ $s = '';
+ if (($undopt = $wgUser->getOption("underline")) != 2) {
+ $underline = $undopt ? 'underline' : 'none';
+ $s .= "a { text-decoration: $underline; }\n";
+ }
+ if( $wgUser->getOption( 'highlightbroken' ) ) {
+ $s .= "a.new, #quickbar a.new { /*color: #CC2200;*/ }\n";
+ } else {
+ $s .= <<<END
+a.new, #quickbar a.new,
+a.stub, #quickbar a.stub {
+ color: inherit;
+ text-decoration: inherit;
}
+a.new:after, #quickbar a.new:after {
+ content: "?";
+ color: /*#CC2200;*/
+ text-decoration: $underline;
+}
+a.stub:after, #quickbar a.stub:after {
+ content: "!";
+ color: /*#772233;*/
+ text-decoration: $underline;
+}
+END;
+ }
+ if( $wgUser->getOption( 'justify' ) ) {
+ $s .= "#article, #bodyContent { text-align: justify; }\n";
+ }
+ if( !$wgUser->getOption( 'showtoc' ) ) {
+ $s .= "#toc { display: none; }\n";
+ }
+ if( !$wgUser->getOption( 'editsection' ) ) {
+ $s .= ".editsection { display: none; }\n";
+ }
+ return $s;
+ }
+}
/**
* Generic wrapper for template functions, with interface
Index: includes/SpecialPreferences.php
===================================================================
--- includes/SpecialPreferences.php (revisión: 36)
+++ includes/SpecialPreferences.php (copia de trabajo)
@@ -192,8 +192,9 @@
global $wgEmailAuthentication, $wgMinimalPasswordLength;
global $wgAuth;
-
- if ( '' != $this->mNewpass ) {
+ //EOL
+ //pwd change disabled
+/* if ( '' != $this->mNewpass ) {
if ( $this->mNewpass != $this->mRetypePass ) {
$this->mainPrefsForm( 'error', wfMsg( 'badretype' ) );
return;
@@ -216,6 +217,7 @@
$this->mNewpass = $this->mOldpass = $this->mRetypePass = '';
}
+ */
$wgUser->setRealName( $this->mRealName );
if( $wgUser->getOption( 'language' ) !== $this->mUserLanguage ) {
@@ -632,28 +634,30 @@
}
$wgOut->addHTML('</table>');
- # Password
- $this->mOldpass = htmlspecialchars( $this->mOldpass );
- $this->mNewpass = htmlspecialchars( $this->mNewpass );
- $this->mRetypePass = htmlspecialchars( $this->mRetypePass );
+ # Password
+ //EOL
+ //pwd change disabled
+// $this->mOldpass = htmlspecialchars( $this->mOldpass );
+// $this->mNewpass = htmlspecialchars( $this->mNewpass );
+// $this->mRetypePass = htmlspecialchars( $this->mRetypePass );
+//
+// $wgOut->addHTML( '<fieldset><legend>' . wfMsg( 'changepassword' ) . '</legend><table>');
+// $wgOut->addHTML(
+// $this->addRow(
+// '<label for="wpOldpass">' . wfMsg( 'oldpassword' ) . '</label>',
+// "<input type='password' name='wpOldpass' id='wpOldpass' value=\"{$this->mOldpass}\" size='20' />"
+// ) .
+// $this->addRow(
+// '<label for="wpNewpass">' . wfMsg( 'newpassword' ) . '</label>',
+// "<input type='password' name='wpNewpass' id='wpNewpass' value=\"{$this->mNewpass}\" size='20' />"
+// ) .
+// $this->addRow(
+// '<label for="wpRetypePass">' . wfMsg( 'retypenew' ) . '</label>',
+// "<input type='password' name='wpRetypePass' id='wpRetypePass' value=\"{$this->mRetypePass}\" size='20' />"
+// ) .
+// "</table>\n" .
+// $this->getToggle( "rememberpassword" ) . "</fieldset>\n\n" );
- $wgOut->addHTML( '<fieldset><legend>' . wfMsg( 'changepassword' ) . '</legend><table>');
- $wgOut->addHTML(
- $this->addRow(
- '<label for="wpOldpass">' . wfMsg( 'oldpassword' ) . '</label>',
- "<input type='password' name='wpOldpass' id='wpOldpass' value=\"{$this->mOldpass}\" size='20' />"
- ) .
- $this->addRow(
- '<label for="wpNewpass">' . wfMsg( 'newpassword' ) . '</label>',
- "<input type='password' name='wpNewpass' id='wpNewpass' value=\"{$this->mNewpass}\" size='20' />"
- ) .
- $this->addRow(
- '<label for="wpRetypePass">' . wfMsg( 'retypenew' ) . '</label>',
- "<input type='password' name='wpRetypePass' id='wpRetypePass' value=\"{$this->mRetypePass}\" size='20' />"
- ) .
- "</table>\n" .
- $this->getToggle( "rememberpassword" ) . "</fieldset>\n\n" );
-
# <FIXME>
# Enotif
if ($wgEnableEmail) {
Index: includes/Block.php
===================================================================
--- includes/Block.php (revisión: 36)
+++ includes/Block.php (copia de trabajo)
@@ -316,7 +316,9 @@
if ( $this->mAddress == '' ) {
$condition = array( 'ipb_id' => $this->mId );
} else {
- $condition = array( 'ipb_address' => $this->mAddress );
+ //EOL
+// $condition = array( 'ipb_address' => $this->mAddress );
+ $condition = array( 'ipb_user' => $this->mAddress );
}
return( $dbw->delete( 'ipblocks', $condition, $fname ) > 0 ? true : false );
}
Index: includes/LogPage.php
===================================================================
--- includes/LogPage.php (revisión: 36)
+++ includes/LogPage.php (copia de trabajo)
@@ -190,10 +190,16 @@
if( substr( $title->getText(), 0, 1 ) == '#' ) {
$titleLink = $title->getText();
} else {
- $titleLink = $skin->makeLinkObj( $title, $title->getText() );
- $titleLink .= ' (' . $skin->makeKnownLinkObj( Title::makeTitle( NS_SPECIAL, 'Contributions/' . $title->getDBkey() ), wfMsg( 'contribslink' ) ) . ')';
+ //EOL
+// $titleLink = $skin->makeLinkObj( $title, $title->getText() );
+// $titleLink .= ' (' . $skin->makeKnownLinkObj( Title::makeTitle( NS_SPECIAL, 'Contributions/' . $title->getDBkey() ), wfMsg( 'contribslink' ) ) . ')';
+ $titleLink = $title->getText();
}
break;
+ //EOL
+ case 'rights':
+ $titleLink = $title->getText();
+ break;
default:
$titleLink = $skin->makeLinkObj( $title );
}
Index: includes/SpecialUnusedimages.php
===================================================================
--- includes/SpecialUnusedimages.php (revisión: 36)
+++ includes/SpecialUnusedimages.php (copia de trabajo)
@@ -56,7 +56,9 @@
# Last modified date
. ' . . '.$wgLang->timeanddate($result->value)
# Link to username
- . ' . . '.$skin->makeLinkObj( Title::makeTitle( NS_USER, $result->img_user_text ), $result->img_user_text)
+ //EOL
+// . ' . . '.$skin->makeLinkObj( Title::makeTitle( NS_USER, $result->img_user_text ), $result->img_user_text)
+ . ' . . '.'<a href="'. EOL_PROFILE .$result->img_user."\">$result->img_user_text</a>"
# If there is a description, show it
. $skin->commentBlock( $wgContLang->convert( $result->img_description ) );
Index: includes/SpecialListusers.php
===================================================================
--- includes/SpecialListusers.php (revisión: 36)
+++ includes/SpecialListusers.php (copia de trabajo)
@@ -1,4 +1,10 @@
<?php
+
+//EOL
+//redirect to forum member list
+header('Location: /memberlist.php');
+exit;
+
# Copyright (C) 2004 Brion Vibber, lcrocker, Tim Starling,
# Domas Mituzas, Ashar Voultoiz, Jens Frank, Zhengzhu.
#
Index: includes/SpecialContributions.php
===================================================================
--- includes/SpecialContributions.php (revisión: 36)
+++ includes/SpecialContributions.php (copia de trabajo)
@@ -6,11 +6,11 @@
/** @package MediaWiki */
class contribs_finder {
- var $username, $offset, $limit, $namespace;
+ var $userid, $offset, $limit, $namespace;
var $dbr;
- function contribs_finder($username) {
- $this->username = $username;
+ function contribs_finder($userid) {
+ $this->userid = $userid;
$this->namespace = false;
$this->dbr =& wfGetDB(DB_SLAVE);
}
@@ -53,13 +53,16 @@
function get_user_cond() {
$condition = '';
- if ($this->username == 'newbies') {
+ if ($this->userid == 'newbies') {
$max = $this->dbr->selectField('user', 'max(user_id)', false, 'make_sql');
$condition = '>' . (int)($max - $max / 100);
}
if ($condition == '') {
- $condition = ' rev_user_text=' . $this->dbr->addQuotes($this->username);
+ //EOL
+// $condition = ' rev_user_text=' . $this->dbr->addQuotes($this->username);
+// $condition = ' UPPER(rev_user_text)=UPPER(' . $this->dbr->addQuotes($this->username).')';
+ $condition = ' rev_user=' . $this->userid ;
$index = 'usertext_timestamp';
} else {
$condition = ' rev_user '.$condition ;
@@ -161,14 +164,15 @@
$wgOut->errorpage('notargettitle', 'notargettext');
return;
}
+
+ $target=intval($target);
+// $nt = Title::newFromURL( $target );
+// if (!$nt) {
+// $wgOut->errorpage( 'notargettitle', 'notargettext' );
+// return;
+// }
+// $nt =& Title::makeTitle(NS_USER, $nt->getDBkey());
- $nt = Title::newFromURL( $target );
- if (!$nt) {
- $wgOut->errorpage( 'notargettitle', 'notargettext' );
- return;
- }
- $nt =& Title::makeTitle(NS_USER, $nt->getDBkey());
-
list( $limit, $offset) = wfCheckLimits();
$offset = $wgRequest->getVal('offset');
/* Offset must be an integral. */
@@ -179,7 +183,8 @@
$urlbits = 'target=' . wfUrlEncode($target);
$myurl = $title->escapeLocalURL($urlbits);
- $finder = new contribs_finder(($target == 'newbies') ? 'newbies' : $nt->getText());
+// $finder = new contribs_finder(($target == 'newbies') ? 'newbies' : $nt->getText());
+ $finder = new contribs_finder(($target == 'newbies') ? 'newbies' : $target);
$finder->set_limit($limit);
$finder->set_offset($offset);
@@ -211,30 +216,37 @@
}
$sk = $wgUser->getSkin();
+
+ $username = User::whoIs($target);
- $id = User::idFromName($nt->getText());
+ //EOL
+// if ( 0 == $id ) {
+// $ul = $nt->getText();
+// } else {
+// $ul = $sk->makeLinkObj( $nt, htmlspecialchars( $nt->getText() ) );
+// $userCond = '=' . $id;
+// }
+// $talk = $nt->getTalkPage();
- if ( 0 == $id ) {
- $ul = $nt->getText();
- } else {
- $ul = $sk->makeLinkObj( $nt, htmlspecialchars( $nt->getText() ) );
- $userCond = '=' . $id;
- }
- $talk = $nt->getTalkPage();
- if( $talk ) {
- # Talk page link
- $tools[] = $sk->makeLinkObj( $talk, $wgLang->getNsText( NS_TALK ) );
- if( ( $id != 0 && $wgSysopUserBans ) || ( $id == 0 && User::isIP( $nt->getText() ) ) ) {
- # Block link
- if( $wgUser->isAllowed( 'block' ) )
- $tools[] = $sk->makeKnownLinkObj( Title::makeTitle( NS_SPECIAL, 'Blockip/' . $nt->getDBkey() ), wfMsgHtml( 'blocklink' ) );
- # Block log link
- $tools[] = $sk->makeKnownLinkObj( Title::makeTitle( NS_SPECIAL, 'Log' ), htmlspecialchars( LogPage::logName( 'block' ) ), 'type=block&page=' . $nt->getPrefixedUrl() );
- }
+ $ul = '<a href="'. EOL_PROFILE .$target.'">'. $username .'</a>';
+
+// if( $talk ) {
+// # Talk page link
+// $tools[] = $sk->makeLinkObj( $talk, $wgLang->getNsText( NS_TALK ) );
+// if( ( $id != 0 && $wgSysopUserBans ) || ( $id == 0 && User::isIP( $nt->getText() ) ) ) {
+// # Block link
+// if( $wgUser->isAllowed( 'block' ) )
+// $tools[] = $sk->makeKnownLinkObj( Title::makeTitle( NS_SPECIAL, 'Blockip/' . $nt->getDBkey() ), wfMsgHtml( 'blocklink' ) );
+// # Block log link
+// $tools[] = $sk->makeKnownLinkObj( Title::makeTitle( NS_SPECIAL, 'Log' ), htmlspecialchars( LogPage::logName( 'block' ) ), 'type=block&page=' . $nt->getPrefixedUrl() );
+// }
+// }
+
# Other logs link
- $tools[] = $sk->makeKnownLinkObj( Title::makeTitle( NS_SPECIAL, 'Log' ), wfMsgHtml( 'log' ), 'user=' . $nt->getPartialUrl() );
+// $tools[] = $sk->makeKnownLinkObj( Title::makeTitle( NS_SPECIAL, 'Log' ), wfMsgHtml( 'log' ), 'user=' . $nt->getPartialUrl() );
+ $tools[] = $sk->makeKnownLinkObj( Title::makeTitle( NS_SPECIAL, 'Log' ), wfMsgHtml( 'log' ), 'user=' . $target );
$ul .= ' (' . implode( ' | ', $tools ) . ')';
- }
+// } EOL
if ($target == 'newbies') {
$ul = wfMsg ('newbies');
@@ -377,10 +389,12 @@
if( $wgUser->isAllowed('rollback') ) {
$extraRollback = $wgRequest->getBool( 'bot' ) ? '&bot=1' : '';
$extraRollback .= '&token=' . urlencode(
- $wgUser->editToken( array( $page->getPrefixedText(), $row->rev_user_text ) ) );
+ $wgUser->editToken( array( $page->getPrefixedText(), $row->rev_user ) ) );
$topmarktext .= ' ['. $sk->makeKnownLinkObj( $page,
$messages['rollbacklink'],
- 'action=rollback&from=' . urlencode( $row->rev_user_text ) . $extraRollback ) .']';
+ //EOL
+// 'action=rollback&from=' . urlencode( $row->rev_user_text ) . $extraRollback ) .']';
+ 'action=rollback&from=' . urlencode( $row->rev_user ) . $extraRollback ) .']';
}
}